Retrieving a copy of a type
# S3 method for types_env
$(x, name)# S3 method for types_env
[[(x, name)
Returns an object that is a copy of a type that was requested
The environment to request it from
The name of the type that is requested
Holger Hoefling
The types are stored in the environment h5types. These types should not be accessed
directly. Therefor, the $-operator is overloaded to ensure that every type that is accessed is a copy of the
original type