get_id: Get the id of an H5RefClass

View source: R/R6Classes_H5D.R

get_idR Documentation

Get the id of an H5RefClass

Description

Get the id of an H5RefClass

Usage

get_id(obj)

Arguments

obj

Object to get the id from

Details

If it is a H5RefClass, returns the id, otherwise returns the object itself as it assumes it is already an id.

Value

The id itself

Author(s)

Holger Hoefling


hdf5r documentation built on Sept. 7, 2026, 9:08 a.m.