h5version: Return the version of the HDF5-API

View source: R/Misc.R

h5versionR Documentation

Return the version of the HDF5-API

Description

Return the version of the HDF5-API

Usage

h5version(verbose = TRUE)

Arguments

verbose

Should the information be printed to the screen as well

Details

Return the version of the HDF5-API and print it to the screen if requested

Value

Version of the underlying HDF5 API as a string

Author(s)

Holger Hoefling


hdf5r documentation built on Sept. 7, 2026, 9:08 a.m.